==> sources_fancymenu_fabric_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/customization/action/actions/level/JoinServerAction.java <==
package de.keksuccino.fancymenu.customization.action.actions.level;

import de.keksuccino.fancymenu.customization.action.Action;
import de.keksuccino.fancymenu.mixin.mixins.common.client.IMixinServerList;
import de.keksuccino.fancymenu.util.LocalizationUtils;
import de.keksuccino.fancymenu.util.rendering.ui.screen.queueable.QueueableNotificationScreen;
import de.keksuccino.fancymenu.util.rendering.ui.screen.queueable.QueueableScreenHandler;
import de.keksuccino.konkrete.math.MathUtils;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_412;
import net.minecraft.class_419;
import net.minecraft.class_424;
import net.minecraft.class_437;
import net.minecraft.class_442;
import net.minecraft.class_639;
import net.minecraft.class_641;
import net.minecraft.class_642;
import net.minecraft.client.gui.screens.*;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class JoinServerAction extends Action {

    private static final Logger LOGGER = LogManager.getLogger();
    private static final boolean IS_LAN = false;

    private static long lastJoinErrorTrigger = -1;

    public JoinServerAction() {
        super("joinserver");
    }

    @Override
    public boolean canRunAsync() {
        return false;
    }

    @Override
    public boolean hasValue() {
        return true;
    }

    @Override
    public void execute(@Nullable String value) {
        if (class_310.method_1551().field_1687 != null) {
            long now = System.currentTimeMillis();
            if ((lastJoinErrorTrigger + 20000) < now) {
                lastJoinErrorTrigger = now;
                QueueableScreenHandler.addToQueue(new QueueableNotificationScreen(class_2561.method_43471("fancymenu.actions.errors.cannot_join_world_while_in_world")));
            }
            return;
        }
        if (value != null) {
            if (class_310.method_1551().field_1755 instanceof class_419) {
                class_310.method_1551().method_1507(new class_442());
            }
            if (!(class_310.method_1551().field_1755 instanceof JoinServerBridgeScreen) && !(class_310.method_1551().field_1755 instanceof class_412)) {
                try {

                    class_437 current = class_310.method_1551().field_1755;

                    class_310.method_1551().method_1507(new JoinServerBridgeScreen());

                    String ip = value.replace(" ", "");
                    int port = 25565;
                    if (ip.contains(":")) {
                        String portString = ip.split(":", 2)[1];
                        ip = ip.split(":", 2)[0];
                        if (MathUtils.isInteger(portString)) {
                            port = Integer.parseInt(portString);
                        }
                    }
                    class_642 d = null;
                    class_641 l = new class_641(class_310.method_1551());
                    l.method_2981();
                    for (class_642 data : ((IMixinServerList) l).getServerListFancyMenu()) {
                        if (data.field_3761.equals(value.replace(" ", ""))) {
                            d = data;
                            break;
                        }
                    }
                    if (d == null) {
                        d = new class_642(value.replace(" ", ""), value.replace(" ", ""), IS_LAN);
                        l.method_2988(d, false);
                        l.method_2987();
                    }
                    if (current == null) current = new class_442();

                    class_412.method_36877(current, class_310.method_1551(), new class_639(ip, port), d);

                } catch (Exception ex) {
                    LOGGER.error("[FANCYMENU] Failed to execute the 'Join Server' action!", ex);
                }
            }
        }
    }

    @Override
    public @NotNull class_2561 getActionDisplayName() {
        return class_2561.method_43471("fancymenu.actions.joinserver");
    }

    @Override
    public @NotNull class_2561[] getActionDescription() {
        return LocalizationUtils.splitLocalizedLines("fancymenu.actions.joinserver.desc");
    }

    @Override
    public class_2561 getValueDisplayName() {
        return class_2561.method_43471("fancymenu.actions.joinserver.desc.value");
    }

    @Override
    public String getValueExample() {
        return "exampleserver.com:25565";
    }

    private static class JoinServerBridgeScreen extends class_424 {

        public JoinServerBridgeScreen() {
            super(class_2561.method_43473());
        }

        @Override
        public boolean method_25422() {
            return false;
        }

    }

}

==> sources_fancymenu_fabric_3.8.1_MC_1.21.10.jar: de/keksuccino/fancymenu/customization/action/actions/level/JoinServerAction.java <==
package de.keksuccino.fancymenu.customization.action.actions.level;

import com.mojang.blaze3d.systems.RenderSystem;
import de.keksuccino.fancymenu.customization.action.Action;
import de.keksuccino.fancymenu.mixin.mixins.common.client.IMixinServerList;
import de.keksuccino.fancymenu.util.LocalizationUtils;
import de.keksuccino.fancymenu.util.rendering.ui.screen.queueable.QueueableNotificationScreen;
import de.keksuccino.fancymenu.util.rendering.ui.screen.queueable.QueueableScreenHandler;
import de.keksuccino.fancymenu.util.threading.MainThreadTaskExecutor;
import de.keksuccino.konkrete.math.MathUtils;
import net.minecraft.class_2561;
import net.minecraft.class_310;
import net.minecraft.class_412;
import net.minecraft.class_419;
import net.minecraft.class_424;
import net.minecraft.class_437;
import net.minecraft.class_442;
import net.minecraft.class_639;
import net.minecraft.class_641;
import net.minecraft.class_642;
import net.minecraft.client.gui.screens.*;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class JoinServerAction extends Action {

    private static final Logger LOGGER = LogManager.getLogger();

    private static long lastJoinErrorTrigger = -1;

    public JoinServerAction() {
        super("joinserver");
    }

    @Override
    public boolean canRunAsync() {
        return false;
    }

    @Override
    public boolean hasValue() {
        return true;
    }

    @Override
    public void execute(@Nullable String value) {
        if (class_310.method_1551().field_1687 != null) {
            long now = System.currentTimeMillis();
            if ((lastJoinErrorTrigger + 20000) < now) {
                lastJoinErrorTrigger = now;
                QueueableScreenHandler.addToQueue(new QueueableNotificationScreen(class_2561.method_43471("fancymenu.actions.errors.cannot_join_world_while_in_world")));
            }
            return;
        }
        if (value != null) {
            if (class_310.method_1551().field_1755 instanceof class_419) {
                class_310.method_1551().method_1507(new class_442());
            }
            if (!(class_310.method_1551().field_1755 instanceof JoinServerBridgeScreen) && !(class_310.method_1551().field_1755 instanceof class_412)) {
                try {

                    class_437 current = class_310.method_1551().field_1755;

                    class_310.method_1551().method_1507(new JoinServerBridgeScreen());

                    String ip = value.replace(" ", "");
                    int port = 25565;
                    if (ip.contains(":")) {
                        String portString = ip.split(":", 2)[1];
                        ip = ip.split(":", 2)[0];
                        if (MathUtils.isInteger(portString)) {
                            port = Integer.parseInt(portString);
                        }
                    }
                    class_642 d = null;
                    class_641 l = new class_641(class_310.method_1551());
                    l.method_2981();
                    for (class_642 data : ((IMixinServerList) l).getServerListFancyMenu()) {
                        if (data.field_3761.equals(value.replace(" ", ""))) {
                            d = data;
                            break;
                        }
                    }
                    if (d == null) {
                        d = new class_642(value.replace(" ", ""), value.replace(" ", ""), class_642.class_8678.field_45611);
                        l.method_2988(d, false);
                        l.method_2987();
                    }
                    if (current == null) current = new class_442();
                    boolean isQuickPlay = false;

                    class_412.method_36877(current, class_310.method_1551(), new class_639(ip, port), d, isQuickPlay, null);

                } catch (Exception ex) {
                    LOGGER.error("[FANCYMENU] Failed to execute the 'Join Server' action!", ex);
                }
            }
        }
    }

    @Override
    public @NotNull class_2561 getActionDisplayName() {
        return class_2561.method_43471("fancymenu.actions.joinserver");
    }

    @Override
    public @NotNull class_2561[] getActionDescription() {
        return LocalizationUtils.splitLocalizedLines("fancymenu.actions.joinserver.desc");
    }

    @Override
    public class_2561 getValueDisplayName() {
        return class_2561.method_43471("fancymenu.actions.joinserver.desc.value");
    }

    @Override
    public String getValueExample() {
        return "exampleserver.com:25565";
    }

    private static class JoinServerBridgeScreen extends class_424 {

        public JoinServerBridgeScreen() {
            super(class_2561.method_43473());
        }

        @Override
        public boolean method_25422() {
            return false;
        }

    }

}
